@@ -146,7 +146,9 @@ def test_docs_latest(mapp, testapp):
     # navigation shows latest registered version
     navigation_links = r.html.select("#navigation a")
     assert navigation_links[3].text == '2.6'
-    # the content is from latest docs though
+    # there is no warning
+    assert r.html.select('.infonote') == []
+    # and the content matches
     r = testapp.xget(200, iframe.attrs['src'])
     assert r.text == "<html><body>2.6</body></html>"
     # now we register a newer version, but docs should still be 2.6
@@ -157,7 +159,10 @@ def test_docs_latest(mapp, testapp):
     # navigation shows latest registered version
     navigation_links = r.html.select("#navigation a")
     assert navigation_links[3].text == '2.7'
-    # the content is from latest docs though
+    # there is a warning
+    assert [x.text.strip() for x in r.html.select('.infonote')] == [
+        "The latest available documentation (version 2.6) isn't for the latest available package version."]
+    # and the content is from older uploaded docs
     r = testapp.xget(200, iframe.attrs['src'])
     assert r.text == "<html><body>2.6</body></html>"
     # now we upload newer docs
@@ -170,7 +175,86 @@ def test_docs_latest(mapp, testapp):
     # navigation shows latest registered version
     navigation_links = r.html.select("#navigation a")
     assert navigation_links[3].text == '2.7'
-    # the content is from latest docs though
+    # there is no warning anymore
+    assert r.html.select('.infonote') == []
+    # and the content is from newest docs
+    r = testapp.xget(200, iframe.attrs['src'])
+    assert r.text == "<html><body>2.7</body></html>"
+
+
+@pytest.mark.with_notifier
+def test_docs_stable(mapp, testapp):
+    api = mapp.create_and_use()
+    content = zip_dict({"index.html": "<html><body>2.6</body></html>"})
+    mapp.set_versiondata({"name": "pkg1", "version": "2.6"})
+    mapp.upload_doc("pkg1.zip", content, "pkg1", "2.6", code=200,
+                    waithooks=True)
+    r = testapp.xget(200, api.index + "/pkg1/stable/+d/index.html")
+    iframe, = r.html.findAll('iframe')
+    assert iframe.attrs['src'] == api.index + "/pkg1/stable/+doc/index.html"
+    # navigation shows stable registered version
+    navigation_links = r.html.select("#navigation a")
+    assert navigation_links[3].text == '2.6'
+    # there is no warning
+    assert r.html.select('.infonote') == []
+    # and the content matches
+    r = testapp.xget(200, iframe.attrs['src'])
+    assert r.text == "<html><body>2.6</body></html>"
+    # now we register a newer version, but docs should still be 2.6
+    mapp.set_versiondata({"name": "pkg1", "version": "2.7.a1"}, waithooks=True)
+    r = testapp.xget(200, api.index + "/pkg1/stable/+d/index.html")
+    iframe, = r.html.findAll('iframe')
+    assert iframe.attrs['src'] == api.index + "/pkg1/stable/+doc/index.html"
+    # navigation shows stable registered version
+    navigation_links = r.html.select("#navigation a")
+    assert navigation_links[3].text == '2.6'
+    # there is no warning
+    assert r.html.select('.infonote') == []
+    # and the content is also from stable docs
+    r = testapp.xget(200, iframe.attrs['src'])
+    assert r.text == "<html><body>2.6</body></html>"
+    # now we upload newer docs
+    content = zip_dict({"index.html": "<html><body>2.7.a1</body></html>"})
+    mapp.upload_doc("pkg1.zip", content, "pkg1", "2.7.a1", code=200,
+                    waithooks=True)
+    r = testapp.xget(200, api.index + "/pkg1/stable/+d/index.html")
+    iframe, = r.html.findAll('iframe')
+    assert iframe.attrs['src'] == api.index + "/pkg1/stable/+doc/index.html"
+    # navigation shows stable registered version
+    navigation_links = r.html.select("#navigation a")
+    assert navigation_links[3].text == '2.6'
+    # still no warning
+    assert r.html.select('.infonote') == []
+    # and the content is also still from stable docs
+    r = testapp.xget(200, iframe.attrs['src'])
+    assert r.text == "<html><body>2.6</body></html>"
+    # now we register a newer stable version, but docs should still be 2.6
+    mapp.set_versiondata({"name": "pkg1", "version": "2.7"}, waithooks=True)
+    r = testapp.xget(200, api.index + "/pkg1/stable/+d/index.html")
+    iframe, = r.html.findAll('iframe')
+    assert iframe.attrs['src'] == api.index + "/pkg1/stable/+doc/index.html"
+    # navigation shows latest registered stable version
+    navigation_links = r.html.select("#navigation a")
+    assert navigation_links[3].text == '2.7'
+    # there is a warning
+    assert [x.text.strip() for x in r.html.select('.infonote')] == [
+        "The latest available documentation (version 2.6) isn't for the latest available package version."]
+    # and the content is from older stable upload
+    r = testapp.xget(200, iframe.attrs['src'])
+    assert r.text == "<html><body>2.6</body></html>"
+    # now we upload newer docs
+    content = zip_dict({"index.html": "<html><body>2.7</body></html>"})
+    mapp.upload_doc("pkg1.zip", content, "pkg1", "2.7", code=200,
+                    waithooks=True)
+    r = testapp.xget(200, api.index + "/pkg1/stable/+d/index.html")
+    iframe, = r.html.findAll('iframe')
+    assert iframe.attrs['src'] == api.index + "/pkg1/stable/+doc/index.html"
+    # navigation shows latest registered stable version
+    navigation_links = r.html.select("#navigation a")
+    assert navigation_links[3].text == '2.7'
+    # no warning anymore
+    assert r.html.select('.infonote') == []
+    # the content is now latest stable docs
     r = testapp.xget(200, iframe.attrs['src'])
     assert r.text == "<html><body>2.7</body></html>"
 
